<?php

if (! class_exists( 'WP_Analytify_Addons' ) ) {

	class WP_Analytify_Addons {

		protected $plugins_list;

		/**
		 * Constructor
		 */
		public function __construct() {

			$this->plugins_list = get_plugins();

		}

		/**
		 * Returns a list of addons
		 *
		 * @return array
		 * @since 1.3
		 */
		public function addons() {

			$addons = array(
				'wp_analytify_woo' 	=> (object) array(
					'url'    		=> 'https://wp-analytify.com/add-ons/woocommerce/?utm_medium=pro&utm_source=extensions_page',
					'slug'			=> 'wp-analytify-woocommerce/wp-analytify-woocommerce.php',
					'title'  		=> esc_html__( 'Enhaced E-Commerce Tracking for WooCommerce', 'wp-analytify' ),
					'status'		=> '',
					'description'   => esc_html__( 'Our WooCommerce Addon takes Analytics into next level. And its absolutely no-setup needed. So you get World Class data on your shop by just enabling an add-on. Sweet!', 'wp-analytify' )
					),
				'wp_analytify_dash' => (object) array(
					'url'    		=> 'https://wp-analytify.com/',
					'slug'			=> 'wp-analytify-dashboard/wp-analytify-dashboard.php',
					'title'  		=> sprintf( esc_html__( 'Analytify Stats %1$s on WordPress Dashboard', 'wp-analytify' ), '<br />' ),
					'status'		=> esc_html__( 'Coming soon', 'wp-analytify' ),
					'description'   => sprintf( esc_html__( 'This Add-on dispays your site Analytics as widgets at WordPress Dashboard. %1$s It is completely Free.', 'wp-analytify'), '<br /><br />' )
					),
				);

			return $addons;
		}


		/**
		 * Check plugin status
		 *
		 * @return array
		 * @since 1.3
		 */
		public function check_plugin_status( $slug, $extension ) {

			if( is_plugin_active( $slug ) ) {

				echo sprintf( esc_html__( '%1$s Already Installed %2$s', 'wp-analytify' ), '<button class="button-primary">', '</button>' );

			}else if( array_key_exists( $slug, $this->plugins_list ) ) {
				
				echo sprintf( esc_html__( '%1$s Activate Plugin %2$s', 'wp-analytify' ), '<a href="' . admin_url( 'plugins.php' ) . '" class="button-primary">', '</a>' );

			}else if( is_plugin_inactive( $slug ) ) {

				if( $extension->status != '' )
					echo sprintf( esc_html__( '%1$s Coming Soon %2$s', 'wp-analytify' ), '<a target="_blank" href="' . $extension->url . '" class="button-primary">', '</a>' );
				else
					echo sprintf( esc_html__( '%1$s Get this add-on %2$s', 'wp-analytify' ), '<a target="_blank" href="' . $extension->url . '" class="button-primary">', '</a>' );

			}
		}


	}

}

$obj_wp_analytify_addons = new WP_Analytify_Addons;
$addons = $obj_wp_analytify_addons->addons();
?>

<div class="wrap">

  <h2 class='opt-title'><span id='icon-options-general' class='analytics-options'><img src="<?php echo plugins_url('wp-analytify-pro/images/wp-analytics-logo.png');?>" alt=""></span>
	<?php esc_html_e( 'Extend the functionality of Analytify with these awesome Add-ons', 'wp-analytify' ); ?>
  </h2>

	<div class="tabwrapper">
		<?php
		foreach ( $addons as $name => $extension ) :
			?>
			<div class="wp-extension <?php echo $name; ?>">
				<a target="_blank" href="<?php echo $extension->url; ?>">

					<h3><?php echo $extension->title; ?></h3>
				</a>

				<p><?php echo $extension->description; ?></p>
				<p>
					<?php $obj_wp_analytify_addons->check_plugin_status( $extension->slug, $extension ); ?>
				</p>
			</div>
		<?php endforeach; ?>
	</div>

</div>